coalib.bearlib.languages package
================================

Subpackages
-----------

.. toctree::

    coalib.bearlib.languages.definitions
    coalib.bearlib.languages.documentation

Submodules
----------

coalib.bearlib.languages.Language module
----------------------------------------

.. automodule:: coalib.bearlib.languages.Language
    :members:
    :undoc-members:
    :show-inheritance:

coalib.bearlib.languages.LanguageDefinition module
--------------------------------------------------

.. automodule:: coalib.bearlib.languages.LanguageDefinition
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: coalib.bearlib.languages
    :members:
    :undoc-members:
    :show-inheritance:
